
-- The original lovemenu script is the menu.lua in the same directory.
-- I had to make the following changes:
--  * Added the 'local' keyword before the menu variable so it is not inserted as a global.
--  * Default value for fonts, background, and cursor icon set to nil so that this
--    script can called using a "require" without having to edit the script. This forces
--    us to define certain variables first before calling toggle however.
--  * Allowed WASD as alternatives to moving menu cursor.
--  * Ability to toggle on and off the mouse as a means to move menu cursor.
--  * Ability to set the alpha of the background picture.
--  * Ability to modify title location

local menu = {}

-- These variables point to assets. They cannot be given a value
-- for "default assets", so we set them to nil so everyone
-- knows they exist and will be used.
menu.font_title = nil
menu.font_desc  = nil
menu.font_menu  = nil
menu.icon       = nil
menu.bg         = nil

-- These variables can be given default values.
menu.title_x     = (love.graphics.getWidth()*6/10)/2
menu.title_y     = love.graphics.getHeight()*0.9
menu.bg_alpha    = 63
menu.padding     = 64
menu.option      = 0
menu.state       = 1
menu.run         = false
menu.enablemouse = true

function menu:load(views)
  menu.view = views
  menu:calc_offset()
  menu.iconpos = menu.option*menu.font_menu:getHeight()+menu.offset+menu.font_menu:getHeight()/2
  menu.iconcurpos = menu.iconpos
end

function menu:calc_offset()
  menu.offset = love.graphics.getHeight()/2-(menu.font_menu:getHeight()*#menu.view[menu.state])/2
end

function menu:toggle()
  menu.run = not menu.run
end

menu.title_fade = 0
function menu:draw()
  if menu.run then
    local orig_font = love.graphics.getFont()
    local orig_r, orig_g, orig_b, orig_a
    orig_r, orig_g, orig_b, orig_a = love.graphics.getColor( )
	love.graphics.setColor(255,255,255,menu.bg_alpha)
    love.graphics.draw(menu.bg,0,0,0,love.graphics.getWidth()/menu.bg:getWidth(),love.graphics.getHeight()/menu.bg:getHeight())
    love.graphics.setColor(0,0,0,127)
    love.graphics.rectangle("fill",love.graphics.getWidth()*6/10,0,love.graphics.getWidth()*3/10,love.graphics.getHeight())
    love.graphics.setColor(255,255,255,96+96*math.abs(math.sin(menu.title_fade)))
    love.graphics.setFont(menu.font_title)
    love.graphics.print(
      menu.view[menu.state].title,
      menu.title_x - (menu.font_title:getWidth(menu.view[menu.state].title)/2),
      menu.title_y - (menu.font_title:getHeight())
    )
    love.graphics.setColor(255,255,255,192)
    love.graphics.setFont(menu.font_desc)
    love.graphics.printf(
      menu.view[menu.state].desc,
      love.graphics.getWidth()*1/10,
      love.graphics.getHeight()*1/10,
      love.graphics.getWidth()*4/10,
       "right"
     )
    love.graphics.setFont(menu.font_menu)
    for i,v in ipairs(menu.view[menu.state]) do
      love.graphics.printf(
        v.t,
        love.graphics.getWidth()*6.5/10,
        (i-1)*menu.font_menu:getHeight()+menu.offset,
        love.graphics.getWidth()*2/10,
        "right"
      )
    end
    love.graphics.draw(
      menu.icon,
      love.graphics.getWidth()*8.5/10,
      menu.iconcurpos,--wat
      0,1,1,
      0,
      menu.icon:getHeight()/2
    )
    if orig_font then love.graphics.setFont(orig_font) end
    love.graphics.setColor(orig_r,orig_g,orig_b,orig_a)
  end
end


function menu:update(dt)
  if menu.run then
    menu.title_fade = menu.title_fade + dt
    menu.iconpos = menu.option*menu.font_menu:getHeight()+menu.offset+menu.font_menu:getHeight()/2
    if menu.iconpos > menu.iconcurpos then
      menu.iconcurpos = menu.iconcurpos + math.abs(menu.iconcurpos-menu.iconpos)/2
    elseif menu.iconpos < menu.iconcurpos then
      menu.iconcurpos = menu.iconcurpos - math.abs(menu.iconcurpos-menu.iconpos)/2
    end
	if menu.enablemouse then
      local temp_test = menu:determine_mouse_choice(love.mouse.getX(),love.mouse.getY())
      if temp_test then
        menu.option = temp_test
      end
	end
  end
end

function menu:keypressed(key)
  if menu.run then
    if key == "escape" then
      menu.option = #menu.view[menu.state]-1
    elseif key == "up" or key == "w" then
      menu.option = (menu.option - 1) % #menu.view[menu.state]
    elseif key == "down" or key == "s" then
      menu.option = (menu.option + 1) % #menu.view[menu.state]
    elseif key == "return" or key == "enter" or key ==" " then
      menu:callback_exec()
    end
  end
end

function menu:callback_exec()
  if menu.callback then
    menu:callback(menu.view[menu.state][menu.option+1].cb)
  else
    print("menu:callback not defined.")
  end
end

function menu:setstate(stateid)
  if menu.view[stateid] then
    menu.option = 0
    menu.state = stateid
  else
    print("Menu state does not exist.")
  end
end

function menu:determine_mouse_choice(x,y)
  local x_start = love.graphics.getWidth()*6.5/10
  local limit = love.graphics.getWidth()*2/10
  for i = 1,#menu.view[menu.state] do
    local y_start = (i-1)*menu.font_menu:getHeight()+menu.offset
    if x >= x_start and x <= x_start + limit and y >= y_start and y <= y_start + menu.font_menu:getHeight() then
       return i-1
    end
  end
end

function menu:mousepressed(x,y,button)
  if menu.run then
    local temp_test = menu:determine_mouse_choice(x,y)
    if temp_test then
      menu.option = temp_test
      menu:callback_exec()
    end
  end
end

return menu
