
-- Fall-Winter Demo 2012
-- turtlesort.com
-- Kevin Sacro

-- This scene is where all major gameplay happens.
-- This scene finds all maps in /maps and loads them automatically.

local scene = {}

function scene.init()
	
	game.player  = require 'player'
	game.maps    = require 'lib.exp.atlwrapper'
	game.camera  = require 'camera' 
	
	-- Setup the text system so that the play cannot move
	-- when there is text to scroll through.
	game.text.preDisplayText = function()
		game.player.canMove = false
	end
	
	game.text.postDisplayText = function()
		game.player.canMove = true
	end
	
	-- Event listener needs to be added before the first map is set.
	-- Remember that multiple calls to require returns the same
	-- script object.
	game.maps.addObserver(require 'eventlistener') 
	game.player.addObserver(require 'eventlistener')
	
	-- Find all .tmx files in /maps and define them
	
	local maps = love.filesystem.enumerate('maps')
	
	for _, mapname in pairs(maps) do
		if mapname:ends('.tmx') then
			game.maps.defineMap(mapname)
		end
	end
	
end

function scene.load()

	game.font.setDefaultFont('fonts/PressStart2P/PressStart2P.ttf')

	
	game.maps.setCurrentMap(require 'maps.init')
	--game.maps.setCurrentMap("lobby")
	--game.player.moveTo(18, 10, 'down') -- Player start location
	
	-- Set the player's draw function to be executed after the 'Player' layer is handled
	game.maps.drawAfter['Player'] = game.player.draw
	
	-- A camera target can be any object that has the attributes x and y
	-- defined (as coordinates)
	game.camera.setTarget(game.player)

end

function scene.draw()

	-- This function also implicitly calls the draw function of
	-- the player. This was specified in load().
	game.maps.draw(math.floor(game.camera.x), math.floor(game.camera.y))

end


function scene.update(dt)

	game.player.update(dt)
	game.maps.update(dt) -- Required for fade in/out effects
	game.camera.update(dt)
	
end

function scene.keypressed(key, unicode)
	game.player.keypressed(key, incode)
	
	if key == 'escape' then
		game.text.enabled = false -- Turn off any visible text boxes
		game.transitionTo('mainmenu')
	end
	
end


-- from http://lua-users.org/wiki/StringRecipes
function string.ends(String,End)
   return End=='' or string.sub(String,-string.len(End))==End
end

return scene